# streamtracer

Fast streamline tracing in python

[![Documentation Status](https://readthedocs.org/projects/streamtracer/badge/?version=stable)](https://docs.sunpy.org/projects/streamtracer/en/stable/?badge=stable)
[![Build Status](https://github.com/sunpy/streamtracer/actions/workflows/ci.yml/badge.svg)](https://github.com/sunpy/streamtracer/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/sunpy/streamtracer/branch/master/graph/badge.svg)](https://codecov.io/gh/sunpy/streamtracer)

## Documentation

For full documentation, including installation instructions, see
https://docs.sunpy.org/projects/streamtracer
